@@ -5,142 +5,34 @@ sub _clean_eval { eval $_[0] }
 use strict;
 use warnings;
 
-our $VERSION = '2.006_007';
-$VERSION =~ tr/_//d;
-
 use Sub::Defer qw(defer_sub);
 use Scalar::Util qw(weaken);
-use Exporter ();
-BEGIN { *import = \&Exporter::import }
+use Exporter qw(import);
 use Carp qw(croak);
 BEGIN { our @CARP_NOT = qw(Sub::Defer) }
 use B ();
 BEGIN {
-  my $TRUE  = sub(){!!1};
-  my $FALSE = sub(){!!0};
-  *_HAVE_IS_UTF8          = defined &utf8::is_utf8 ? $TRUE : $FALSE;
-  *_HAVE_PERLSTRING       = defined &B::perlstring ? $TRUE : $FALSE;
-  *_CAN_TRACK_BOOLEANS    = defined &builtin::is_bool ? $TRUE : $FALSE;
-  *_CAN_TRACK_NUMBERS     = defined &builtin::created_as_number ? $TRUE : $FALSE;
-  *_BAD_BACKSLASH_ESCAPE  = _HAVE_PERLSTRING() && "$]" == 5.010_000 ? $TRUE : $FALSE;
-  *_HAVE_HEX_FLOAT        = !$ENV{SUB_QUOTE_NO_HEX_FLOAT} && "$]" >= 5.022 ? $TRUE : $FALSE;
-
-  # This may not be perfect, as we can't tell the format purely from the size
-  # but it should cover the common cases, and other formats are more likely to
-  # be less precise.
-  my $nvsize = 8 * length pack 'F', 0;
-  my $nvmantbits
-    = $nvsize == 16   ? 11
-    : $nvsize == 32   ? 24
-    : $nvsize == 64   ? 53
-    : $nvsize == 80   ? 64
-    : $nvsize == 128  ? 113
-    : $nvsize == 256  ? 237
-                      : 237 # unknown float format
-    ;
-  my $precision = int( log(2)/log(10)*$nvmantbits );
-
-  *_NVSIZE = sub(){$nvsize};
-  *_NVMANTBITS = sub(){$nvmantbits};
-  *_FLOAT_PRECISION = sub(){$precision};
+  *_HAVE_PERLSTRING = defined &B::perlstring ? sub(){1} : sub(){0};
 }
 
+our $VERSION = '2.003000';
+$VERSION = eval $VERSION;
+
 our @EXPORT = qw(quote_sub unquote_sub quoted_from_sub qsub);
 our @EXPORT_OK = qw(quotify capture_unroll inlinify sanitize_identifier);
 
 our %QUOTED;
 
-my %escape;
-if (_BAD_BACKSLASH_ESCAPE) {
-  %escape = (
-    (map +(chr($_) => sprintf '\x%02x', $_), 0 .. 0x31, 0x7f),
-    "\t" => "\\t",
-    "\n" => "\\n",
-    "\r" => "\\r",
-    "\f" => "\\f",
-    "\b" => "\\b",
-    "\a" => "\\a",
-    "\e" => "\\e",
-    (map +($_ => "\\$_"), qw(" \ $ @)),
-  );
-}
-
 sub quotify {
-  my $value = $_[0];
   no warnings 'numeric';
-  BEGIN {
-    warnings->unimport(qw(experimental::builtin))
-      if _CAN_TRACK_BOOLEANS || _CAN_TRACK_NUMBERS;
-  }
-  ! defined $value     ? 'undef()'
-  : _CAN_TRACK_BOOLEANS && builtin::is_bool($value) ? (
-    $value ? '(!!1)' : '(!!0)'
-  )
+  ! defined $_[0]     ? 'undef()'
   # numeric detection
-  : (
-    _CAN_TRACK_NUMBERS
-      ? builtin::created_as_number($value)
-      : (
-        !(_HAVE_IS_UTF8 && utf8::is_utf8($value))
-        && length( (my $dummy = '') & $value )
-        && 0 + $value eq $value
-      )
-  ) ? (
-    $value != $value ? (
-      $value eq (9**9**9*0)
-        ? '(9**9**9*0)'    # nan
-        : '(-(9**9**9*0))' # -nan
-    )
-    : $value == 9**9**9  ? '(9**9**9)'     # inf
-    : $value == -9**9**9 ? '(-9**9**9)'    # -inf
-    : $value == 0 ? (
-      sprintf('%g', $value) eq '-0' ? '-0.0' : '0',
-    )
-    : $value !~ /[e.]/i ? (
-      $value > 0 ? (sprintf '%u', $value)
-                 : (sprintf '%d', $value)
-    )
-    : do {
-      my $float = $value;
-      my $max_factor = int( log( abs($value) ) / log(2) ) - _NVMANTBITS;
-      my $ex_sign = $max_factor > 0 ? 1 : -1;
-      FACTOR: for my $ex (0 .. abs($max_factor)) {
-        my $num = $value / 2**($ex_sign * $ex);
-        for my $precision (_FLOAT_PRECISION .. _FLOAT_PRECISION+2) {
-          my $formatted = sprintf '%0.'.$precision.'g', $num;
-          $float = $formatted
-            if $ex == 0;
-          if ($formatted == $num) {
-            if ($ex) {
-              $float
-                = $formatted
-                . ($ex_sign == 1 ? '*' : '/')
-                . (
-                  $ex > _NVMANTBITS
-                    ? "2**$ex"
-                    : sprintf('%u', 2**$ex)
-                );
-            }
-            last FACTOR;
-          }
-        }
-        if (_HAVE_HEX_FLOAT) {
-          $float = sprintf '%a', $value;
-          last FACTOR;
-        }
-      }
-      "$float";
-    }
-  )
-  : !_CAN_TRACK_BOOLEANS && !length($value) && length( (my $dummy2 = '') & $value ) ? '(!!0)' # false
-  : _BAD_BACKSLASH_ESCAPE && _HAVE_IS_UTF8 && utf8::is_utf8($value) ? do {
-    $value =~ s/(["\$\@\\[:cntrl:]]|[^\x00-\x7f])/
-      $escape{$1} || sprintf('\x{%x}', ord($1))
-    /ge;
-    qq["$value"];
-  }
-  : _HAVE_PERLSTRING ? B::perlstring($value)
-  : qq["\Q$value\E"];
+  : (length( (my $dummy = '') & $_[0] )
+    && 0 + $_[0] eq $_[0]
+    && $_[0] * 0 == 0
+  ) ? $_[0]
+  : _HAVE_PERLSTRING  ? B::perlstring($_[0])
+  : qq["\Q$_[0]\E"];
 }
 
 sub sanitize_identifier {
@@ -163,8 +55,6 @@ sub capture_unroll {
 
 sub inlinify {
   my ($code, $args, $extra, $local) = @_;
-  $args = '()'
-    if !defined $args;
   my $do = 'do { '.($extra||'');
   if ($code =~ s/^(\s*package\s+([a-zA-Z0-9:]+);)//) {
     $do .= $1;
@@ -214,11 +104,7 @@ sub quote_sub {
       unless $subname =~ /^[^\d\W]\w*$/;
   }
   my @caller = caller(0);
-  my ($attributes, $file, $line) = @{$options}{qw(attributes file line)};
-  if ($attributes) {
-    /\A\w+(?:\(.*\))?\z/s || croak "invalid attribute $_"
-      for @$attributes;
-  }
+  my $attributes = $options->{attributes};
   my $quoted_info = {
     name     => $name,
     code     => $code,
@@ -228,8 +114,6 @@ sub quote_sub {
     warning_bits => (exists $options->{warning_bits} ? $options->{warning_bits} : $caller[9]),
     hintshash    => (exists $options->{hintshash}    ? $options->{hintshash}    : $caller[10]),
     ($attributes ? (attributes => $attributes) : ()),
-    ($file       ? (file => $file) : ()),
-    ($line       ? (line => $line) : ()),
   };
   my $unquoted;
   weaken($quoted_info->{unquoted} = \$unquoted);
@@ -241,17 +125,10 @@ sub quote_sub {
     return $sub;
   }
   else {
-    my $deferred = defer_sub(
-      ($options->{no_install} ? undef : $name),
-      sub {
-        $unquoted if 0;
-        unquote_sub($quoted_info->{deferred});
-      },
-      {
-        ($attributes ? ( attributes => $attributes ) : ()),
-        ($name ? () : ( package => $quoted_info->{package} )),
-      },
-    );
+    my $deferred = defer_sub +($options->{no_install} ? undef : $name) => sub {
+      $unquoted if 0;
+      unquote_sub($quoted_info->{deferred});
+    }, ($attributes ? { attributes => $attributes } : ());
     weaken($quoted_info->{deferred} = $deferred);
     weaken($QUOTED{$deferred} = $quoted_info);
     return $deferred;
@@ -261,20 +138,8 @@ sub quote_sub {
 sub _context {
   my $info = shift;
   $info->{context} ||= do {
-    my ($package, $hints, $warning_bits, $hintshash, $file, $line)
-      = @{$info}{qw(package hints warning_bits hintshash file line)};
-
-    $line ||= 1
-      if $file;
-
-    my $line_mark = '';
-    if ($line) {
-      $line_mark = "#line ".($line-1);
-      if ($file) {
-        $line_mark .= qq{ "$file"};
-      }
-      $line_mark .= "\n";
-    }
+    my ($package, $hints, $warning_bits, $hintshash)
+      = @{$info}{qw(package hints warning_bits hintshash)};
 
     $info->{context}
       ="# BEGIN quote_sub PRELUDE\n"
@@ -285,11 +150,9 @@ sub _context {
       ."  \%^H = (\n"
       . join('', map
       "    ".quotify($_)." => ".quotify($hintshash->{$_}).",\n",
-        grep !(ref $hintshash->{$_} && $hintshash->{$_} =~ /\A(?:\w+(?:::\w+)*=)?[A-Z]+\(0x[[0-9a-fA-F]+\)\z/),
         keys %$hintshash)
       ."  );\n"
       ."}\n"
-      .$line_mark
       ."# END quote_sub PRELUDE\n";
   };
 }
@@ -342,25 +205,7 @@ sub unquote_sub {
       . "  }".($name ? "\n  \$\$_UNQUOTED = \\&${name}" : '') . ";\n"
       . "}\n"
       . "1;\n";
-    if (my $debug = $ENV{SUB_QUOTE_DEBUG}) {
-      if ($debug =~ m{^([^\W\d]\w*(?:::\w+)*(?:::)?)$}) {
-        my $filter = $1;
-        my $match
-          = $filter =~ /::$/ ? $package.'::'
-          : $filter =~ /::/  ? $package.'::'.($name||'__ANON__')
-          : ($name||'__ANON__');
-        warn $make_sub
-          if $match eq $filter;
-      }
-      elsif ($debug =~ m{\A/(.*)/\z}s) {
-        my $filter = $1;
-        warn $make_sub
-          if $code =~ $filter;
-      }
-      else {
-        warn $make_sub;
-      }
-    }
+    $ENV{SUB_QUOTE_DEBUG} && warn $make_sub;
     {
       no strict 'refs';
       local *{"${package}::${name}"} if $name;
@@ -371,9 +216,6 @@ sub unquote_sub {
         $e = $@;
       }
       unless ($success) {
-        my $space = length($make_sub =~ tr/\n//);
-        my $line = 0;
-        $make_sub =~ s/^/sprintf "%${space}d: ", ++$line/emg;
         croak "Eval went very, very wrong:\n\n${make_sub}\n\n$e";
       }
       weaken($QUOTED{$$unquoted} = $quoted_info);
@@ -387,11 +229,10 @@ sub qsub ($) {
 }
 
 sub CLONE {
-  my @quoted = map { defined $_ ? (
+  %QUOTED = map { defined $_ ? (
     $_->{unquoted} && ${$_->{unquoted}} ? (${ $_->{unquoted} } => $_) : (),
     $_->{deferred} ? ($_->{deferred} => $_) : (),
   ) : () } values %QUOTED;
-  %QUOTED = @quoted;
   weaken($_) for values %QUOTED;
 }
 
@@ -402,7 +243,7 @@ __END__
 
 =head1 NAME
 
-Sub::Quote - Efficient generation of subroutines via string eval
+Sub::Quote - efficient generation of subroutines via string eval
 
 =head1 SYNOPSIS
 
@@ -470,40 +311,7 @@ good idea.  For a sub that will most likely be inlined, it is not recommended.
 =item C<package>
 
 The package that the quoted sub will be evaluated in.  If not specified, the
-package from sub calling C<quote_sub> will be used.
-
-=item C<hints>
-
-The value of L<< C<$^H> | perlvar/$^H >> to use for the code being evaluated.
-This captures the settings of the L<strict> pragma.  If not specified, the value
-from the calling code will be used.
-
-=item C<warning_bits>
-
-The value of L<< C<${^WARNING_BITS}> | perlvar/${^WARNING_BITS} >> to use for
-the code being evaluated.  This captures the L<warnings> set.  If not specified,
-the warnings from the calling code will be used.
-
-=item C<%^H>
-
-The value of L<< C<%^H> | perlvar/%^H >> to use for the code being evaluated.
-This captures additional pragma settings.  If not specified, the value from the
-calling code will be used if possible (on perl 5.10+).
-
-=item C<attributes>
-
-The L<perlsub/Subroutine Attributes> to apply to the sub generated.  Should be
-specified as an array reference.  The attributes will be applied to both the
-generated sub and the deferred wrapper, if one is used.
-
-=item C<file>
-
-The apparent filename to use for the code being evaluated.
-
-=item C<line>
-
-The apparent line number
-to use for the code being evaluated.
+sub calling C<quote_sub> will be used.
 
 =back
 
@@ -552,12 +360,9 @@ arguments.
 
  my $quoted_value = quotify $value;
 
-Quotes a single (non-reference) scalar value for use in a code string.  The
-result should reproduce the original value, including strings, undef, integers,
-and floating point numbers.  The resulting floating point numbers (including
-infinites and not a number) should be precisely equal to the original, if
-possible.  The exact format of the resulting number should not be relied on, as
-it may include hex floats or math expressions.
+Quotes a single (non-reference) scalar value for use in a code string.  Numbers
+aren't treated specially and will be quoted as strings, but undef will quoted as
+C<undef()>.
 
 =head2 capture_unroll
 
@@ -596,37 +401,6 @@ Arguments: $identifier
 
 Sanitizes a value so that it can be used in an identifier.
 
-=head1 ENVIRONMENT
-
-=head2 SUB_QUOTE_DEBUG
-
-Causes code to be output to C<STDERR> before being evaled.  Several forms are
-supported:
-
-=over 4
-
-=item C<1>
-
-All subs will be output.
-
-=item C</foo/>
-
-Subs will be output if their code matches the given regular expression.
-
-=item C<simple_identifier>
-
-Any sub with the given name will be output.
-
-=item C<Full::identifier>
-
-A sub matching the full name will be output.
-
-=item C<Package::Name::>
-
-Any sub in the given package (including anonymous subs) will be output.
-
-=back
-
 =head1 CAVEATS
 
 Much of this is just string-based code-generation, and as a result, a few
@@ -715,8 +489,6 @@ arcanez - Justin Hunter (cpan:ARCANEZ) <justin.d.hunter@gmail.com>
 
 kanashiro - Lucas Kanashiro (cpan:KANASHIRO) <kanashiro.duarte@gmail.com>
 
-djerius - Diab Jerius (cpan:DJERIUS) <djerius@cfa.harvard.edu>
-
 =head1 COPYRIGHT
 
 Copyright (c) 2010-2016 the Sub::Quote L</AUTHOR> and L</CONTRIBUTORS>
